#ifndef redhat_h
#define redhat_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_redhat: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_redhat */
public:
	MODULE_redhat (void);
	int dohtml (const char *key);
	int execmain (int argc, char *argv[], bool);
	int message (const char *msg,
		 int argc,
		 const char *argv[]);
    /*~PROTOEND~ MODULE_redhat */
};

class HOSTS;
class HOSTINFO;
class VIEWITEMS;
class ROUTES;
class PPPONE;
class USER;
class SHADOW;
class SERVICES;

extern const char scripts_path[];

#include "redhat.p"

#endif
